'''title'''
__title__ = 'pyfreeproxy'
'''description'''
__description__ = 'FreeProxy: Collecting free proxies from internet.'
'''url'''
__url__ = 'https://github.com/CharlesPikachu/freeproxy'
'''version'''
__version__ = '0.1.5'
'''author'''
__author__ = 'Zhenchao Jin'
'''email'''
__email__ = 'charlesblwx@gmail.com'
'''license'''
__license__ = 'Apache License 2.0'
'''copyright'''
__copyright__ = 'Copyright 2022-2025 Zhenchao Jin'